/*******************
VARIABLES
*******************/
var creativeId = "Banner"; //Use anything that uniquely identifies this creative
var creativeVersion = "1.0.18"; //0.0.1 during initial dev, 1.0.0 on release, x.x.x once released and receives updates
var lastModified = "2017-08-02";
var lastUploaded = "2017-08-02";
var templateVersion = "2.0.24";
var bannerDiv;
var playPauseBtn;
var muteUnmuteBtn;
var containerOverVideo, imgOverVideo;
var lastFrame;
var clickthroughButton;
var video;
var sdkData;
var isMRAID;

/*******************
INITIALIZATION
*******************/
initializeCSSVariables();

function checkIfAdKitReady(event) {
	adkit.onReady(initializeCreative);
}

function initializeCreative(event) {
	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr === "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);
    
	window.registerInteraction = function() {}; //overwrite rI function because it will never actually be called
	initializeGlobalVariables();
    lastFrame.src = EB.getAssetUrl('./AdditionalAssets/last_frame.jpg',3);
    bannerDiv.style.backgroundImage = "url("+EB.getAssetUrl('./AdditionalAssets/background.jpg',1);+")";
    video.src = EB.getAssetUrl('./AdditionalAssets/video.mp4',4);
	try{imgOverVideo.src = EB.getAssetUrl('./AdditionalAssets/imgOverVideo.png',5);}catch(e){};
	initializeVideoTracking();
	addEventListeners();
    checkSocialMediaSetting();
}

function initializeCSSVariables() {
var style = document.createElement('style');
  style.innerHTML = '#video-container{'+videoPlayer_CSS+'}#lastframe{'+videoLastFrame_CSS+'}#video-controls{'+videoControllers_CSS+'}button{width:'+videoControllers_Buttons_Dimension_CSS+'; height: auto;}';
  document.head.appendChild(style);
}

function initializeCSSVariables_onVideoEnd() {
var style = document.createElement('style');
  style.innerHTML = '#video-controls{'+videoControllers_CSS_onVideoEnd+'}';
  document.head.appendChild(style);
}

function initializeGlobalVariables() {
	bannerDiv = document.getElementById("banner");
	clickthroughButton = document.getElementById("clickthroughButton");
	video = document.getElementById("video");
    playPauseBtn = document.getElementById("play-pause");
    muteUnmuteBtn = document.getElementById("mute-unmute");
    containerOverVideo = document.getElementById("containerOverVideo");
	imgOverVideo = document.getElementById("imgOverVideo");
    lastFrame = document.getElementById("lastframe");

	if (!isMRAID) {
		sdkData = EB.getSDKData();
		isMRAID = sdkData !== null && sdkData.SDKType === "MRAID";
	}
}

function initializeVideoTracking() {
	videoTrackingModule = new EBG.VideoModule(video);
}

function addEventListeners() {
	bannerDiv.addEventListener("click", onClickthrough);
    video.addEventListener("click", onClickthroughVideo);
    playPauseBtn.addEventListener("click", toggleVideoPlay);
    muteUnmuteBtn.addEventListener("click",toggleAudio );
    video.addEventListener("ended", handleVideoEnd);
    video.addEventListener("playing", handlePlaying);
    video.addEventListener("pause", handlePause);
}

function registerInteraction() {
	//Register your automatic and user interactions here and the platform will parse them on workspace upload. This function will not be called.
	//Example: 'Left_Gutter_Viewed'

	//EB.automaticEventCounter("interactionName1");
	//EB.automaticEventCounter("interactionName2");

    //uncomment code here below if you want to use social media btns
    /*
	EB.userActionCounter("click_facebook");
	EB.userActionCounter("click_youtube");
    EB.userActionCounter("click_instagram");
    EB.userActionCounter("click_pinterest");
    */
}

/*******************
EVENT HANDLERS
*******************/
function onClickthrough(e) {
    e.stopPropagation();
    pauseVideo();
	EB.clickthrough("click_banner");
}
function onClickthroughVideo(e) {
    e.stopPropagation();
    pauseVideo();
	EB.clickthrough("click_videoplayer");
    console.log("click on video");
}

function handlePlaying(){
    setBtnStatusTo("pause");
    hideLastframe();
    
    if (typeof videoControllers_CSS_onVideoEnd !== 'undefined') {
        initializeCSSVariables();
    }
}

function handlePause(){
    setBtnStatusTo("play");
   hideLastframe();
}

function handleVideoEnd(){
    setBtnStatusTo("replay");
    showLastframe();
    
    if (typeof videoControllers_CSS_onVideoEnd !== 'undefined') {
        initializeCSSVariables_onVideoEnd();
    }
}

/*******************
VIDEO UTILITIES
*******************/

function toggleVideoPlay(e){
    e.stopPropagation();
    if(checkVideoPlaying()){
        video.pause();
        setBtnStatusTo("play");
    }else{
        video.play();
        setBtnStatusTo("pause");
    }
}

function toggleAudio(e){
    e.stopPropagation();
     if(video.muted){
       video.muted = false;
        setBtnStatusTo("mute");
    }else{
       video.muted = true;
        setBtnStatusTo("unmute");
    }
}

function showLastframe(){
    lastFrame.style.opacity = 1;
    containerOverVideo.style.opacity = 0;
}
function hideLastframe(){
    lastFrame.style.opacity = 0;
    containerOverVideo.style.opacity = 1;
}

function setBtnStatusTo(_status){
    switch(_status) {
      case "play":
        playPauseBtn.children[0].src = "images/controls/play.svg";
        break;
      case "pause":
        playPauseBtn.children[0].src = "images/controls/pause.svg";
        break;
    case "mute":
        muteUnmuteBtn.children[0].src = "images/controls/unmute.svg";
        break;
    case "unmute":
         muteUnmuteBtn.children[0].src = "images/controls/mute.svg";
        break;
    case "replay":
        playPauseBtn.children[0].src = "images/controls/replay.svg";
        break;
      default:
        // code block
    }
}

function checkVideoPlaying(){
    if(video.currentTime > 0 && !video.paused && !video.ended){
        return true;
    }else{
        return false;
    }
}

function checkSocialMediaSetting(){
    if(socialMediaButton){
        //uncomment code here below if you want to use social media btns
        /*
       document.getElementById("facebook").addEventListener("click", function(){EB.userActionCounter("click_facebook", facebook_url)});
        document.getElementById("youtube").addEventListener("click", function(){EB.userActionCounter("click_youtube", youtube_url)});
        document.getElementById("instagram").addEventListener("click", function(){EB.userActionCounter("click_instagram", instagram_url)});
        document.getElementById("pinterest").addEventListener("click", function(){EB.userActionCounter("click_pinterest", pinterest_url)});
        */
    }
}

/*******************
UTILITIES
*******************/
function pauseVideo() {
	if (video) {
		video.pause();
	}
}



window.addEventListener("load", checkIfAdKitReady);